==> gmssl-sdf-impl-yunhsm-0.1.3-20190730.071518-6-sources.jar: com/xdja/hsm/api/alg/AlgId.java <==
package com.xdja.hsm.api.alg;

public class AlgId {

    /*****************************
     * 分组密码算法标识
     *****************************/
    /**
     * SM1算法ECB加密模式
     */
    public static int SGD_SM1_ECB = 0x00000101;

    /**
     * SM1算法CBC加密模式
     */
    public static int SGD_SM1_CBC = 0x00000102;

    /**
     * SM1算法CBC加密模式
     */
    public static int SGD_SM1_MAC = 0x00000110;

    /**
     * SM4算法ECB加密模式
     */
    public static int SGD_SM4_ECB = 0x00000401;

    /**
     * SM4算法CBC加密模式
     */
    public static int SGD_SM4_CBC = 0x00000402;

    /**
     * SM4算法CBC加密模式
     */
    public static int SGD_SM4_MAC = 0x00000410;

    /*****************************
     * 非对称密钥算法标识
     *****************************/
    /**
     * RSA算法
     */
    public static int SGD_RSA = 0x00010000;

    /**
     *SM2椭圆曲线密码算法
     */
    public static int SGD_SM2 = 0x00020100;

    /**
     * SM2椭圆曲线签名算法
     */
    public static int SGD_SM2_1 = 0x00020200;

    /**
     * SM2椭圆曲线密钥交换协议
     */
    public static int SGD_SM2_2 = 0x00020400;

    /**
     * SM2椭圆曲线加密算法
     */
    public static int SGD_SM2_3 = 0x00020800;

    /*****************************
     * 密码杂凑算法标识
     *****************************/
    /**
     * SM3杂凑算法
     */
    public static int SGD_SM3 = 0x00000001;

    /**
     * SHA_1杂凑算法
     */
    public static int SGD_SHA1 = 0x00000002;

    /**
     * SHA_256杂凑算法
     */
    public static int SGD_SHA256 = 0x00000004;

    /*****************************
     * 签名算法标识
     *****************************/
    /**
     * 基于SM3算法和RSA算法的签名
     */
    public static int SGD_SM3_RSA = 0x00010001;

    /**
     * 基于SHA_1算法和RSA算法的签名
     */
    public static int SGD_SHA1_RSA = 0x00010002;

    /**
     * 基于SHA_256算法和RSA算法的签名
     */
    public static int SGD_SHA256_RSA = 0x00010004;

    /**
     * 基于SM3算法和SM2算法的签名
     */
    public static int SGD_SM3_SM2 = 0x00020201;

}

==> gmssl-sdf-impl-yunhsm-1.0.6-20210315.121144-7-sources.jar: com/xdja/hsm/api/alg/AlgId.java <==
package com.xdja.hsm.api.alg;

public class AlgId {

    /*****************************
     * 分组密码算法标识
     *****************************/
    /**
     * SM1算法ECB加密模式
     */
    public static int SGD_SM1_ECB = 0x00000101;

    /**
     * SM1算法CBC加密模式
     */
    public static int SGD_SM1_CBC = 0x00000102;

    /**
     * SM1算法CBC加密模式
     */
    public static int SGD_SM1_MAC = 0x00000110;

    /**
     * SM4算法ECB加密模式
     */
    public static int SGD_SM4_ECB = 0x00000401;

    /**
     * SM4算法CBC加密模式
     */
    public static int SGD_SM4_CBC = 0x00000402;

    /**
     * SM4算法CBC加密模式
     */
    public static int SGD_SM4_MAC = 0x00000410;

    /*****************************
     * 非对称密钥算法标识
     *****************************/
    /**
     * RSA算法
     */
    public static int SGD_RSA = 0x00010000;

    /**
     * SM2椭圆曲线密码算法
     */
    public static int SGD_SM2 = 0x00020100;

    /**
     * SM2椭圆曲线签名算法
     */
    public static int SGD_SM2_1 = 0x00020200;

    /**
     * SM2椭圆曲线密钥交换协议
     */
    public static int SGD_SM2_2 = 0x00020400;

    /**
     * SM2椭圆曲线加密算法
     */
    public static int SGD_SM2_3 = 0x00020800;

    /**
     * ECC-NISTP256椭圆曲线密码算法
     */
    public static int SGD_ECC_NISTP256 = 0x00040100;

    /*****************************
     * 密码杂凑算法标识
     *****************************/
    /**
     * SM3杂凑算法
     */
    public static int SGD_SM3 = 0x00000001;

    /**
     * SHA_1杂凑算法
     */
    public static int SGD_SHA1 = 0x00000002;

    /**
     * SHA_256杂凑算法
     */
    public static int SGD_SHA256 = 0x00000004;

    /*****************************
     * 签名算法标识
     *****************************/
    /**
     * 基于SM3算法和RSA算法的签名
     */
    public static int SGD_SM3_RSA = 0x00010001;

    /**
     * 基于SHA_1算法和RSA算法的签名
     */
    public static int SGD_SHA1_RSA = 0x00010002;

    /**
     * 基于SHA_256算法和RSA算法的签名
     */
    public static int SGD_SHA256_RSA = 0x00010004;

    /**
     * 基于SM3算法和SM2算法的签名
     */
    public static int SGD_SM3_SM2 = 0x00020201;

    /**
     * AES-CCM-128 算法
     */
    public static int SGD_AES_CCM = 0x00001111;

    /**
     * AES-CCM-192 算法
     */
    public static int SGD_AES192_CCM = 0x00001211;

    /**
     * AES-CCM-256 算法
     */
    public static int SGD_AES256_CCM = 0x00001411;

}
